@@ -6,6 +6,9 @@ use Omnipay\Tests\TestCase;
 
 class CreditCardTest extends TestCase
 {
+    /** @var CreditCard */
+    private $card;
+
     public function setUp()
     {
         $this->card = new CreditCard;
@@ -109,6 +112,21 @@ class CreditCardTest extends TestCase
         $this->assertArrayHasKey(CreditCard::BRAND_VISA, $brands);
     }
 
+    public function testCustomSupportedBrand()
+    {
+        $this->card->addSupportedBrand('omniexpress', '/^9\d{12}(\d{3})?$/');
+        $this->assertArrayHasKey('omniexpress', $this->card->getSupportedBrands());
+    }
+
+    public function testCustomBrandWorks()
+    {
+        $this->card->addSupportedBrand('omniexpress', '/^9\d{12}(\d{3})?$/');
+        $this->assertArrayHasKey('omniexpress', $this->card->getSupportedBrands());
+        $this->card->setNumber('9111111111111110');
+        $this->card->validate();
+        $this->assertEquals('omniexpress', $this->card->getBrand());
+    }
+
     public function testTitle()
     {
         $this->card->setTitle('Mr.');
@@ -309,6 +327,26 @@ class CreditCardTest extends TestCase
         $this->assertEquals('456', $this->card->getCvv());
     }
 
+    public function testTracks()
+    {
+        $this->card->setTracks('%B4242424242424242^SMITH/JOHN ^1520126100000000000000444000000?;4242424242424242=15201269999944401?');
+        $this->assertSame('%B4242424242424242^SMITH/JOHN ^1520126100000000000000444000000?;4242424242424242=15201269999944401?', $this->card->getTracks());
+    }
+
+    public function testShouldReturnTrack1()
+    {
+        $this->card->setTracks('%B4242424242424242^SMITH/JOHN ^1520126100000000000000444000000?;4242424242424242=15201269999944401?');
+        $actual = $this->card->getTrack1();
+        $this->assertEquals('%B4242424242424242^SMITH/JOHN ^1520126100000000000000444000000?', $actual);
+    }
+
+    public function testShouldReturnTrack2()
+    {
+        $this->card->setTracks('%B4242424242424242^SMITH/JOHN ^1520126100000000000000444000000?;4242424242424242=15201269999944401?');
+        $actual = $this->card->getTrack2();
+        $this->assertEquals(';4242424242424242=15201269999944401?', $actual);
+    }
+
     public function testIssueNumber()
     {
         $this->card->setIssueNumber('12');
